import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { useEffect, useState } from "react";
import { createRoot } from 'react-dom/client';
import { Box, Button, ButtonGroup } from '@primer/react';
import Jupyter from '../jupyter/Jupyter';
import { useJupyter } from '../jupyter/JupyterContext';
import Kernel from '../jupyter/services/kernel/Kernel';
import Notebook from '../components/notebook/Notebook';
import CellSidebarDefault from '../components/notebook/cell/sidebar/CellSidebarDefault';
import notebookExample from './NotebookExample1.ipynb.json';
import "./../../style/index.css";
const NOTEBOOK_UID = 'notebook-unmount-id';
const NotebookUnmount = () => {
    const [show, setShow] = useState(true);
    const [kernel, setKernel] = useState();
    const { kernelManager } = useJupyter();
    useEffect(() => {
        if (kernelManager) {
            const kernel = new Kernel({ kernelManager, kernelName: "python" });
            setKernel(kernel);
        }
    }, [kernelManager]);
    useEffect(() => {
        if (!show && kernel) {
            kernel.shutdown();
        }
    }, [show]);
    const unmount = () => {
        setShow(false);
    };
    return (_jsxs(_Fragment, { children: [_jsx(Box, { display: "flex", children: _jsx(ButtonGroup, { children: _jsx(Button, { variant: "default", size: "small", onClick: unmount, children: "Unmount" }) }) }), show ?
                kernel && _jsx(Notebook, { uid: NOTEBOOK_UID, kernel: kernel, model: notebookExample, CellSidebar: CellSidebarDefault, height: "700px" })
                :
                    _jsx(_Fragment, { children: "The notebook is unmounted. The connections to the kernel should not happen any more (check the Network tab in your devtools)." })] }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(Jupyter, { lite: false, terminals: true, startDefaultKernel: false, children: _jsx(NotebookUnmount, {}) }));
//# sourceMappingURL=JupyterExampleUnmount.js.map